/*
 *  markedexec
 * works like exec ... & except that it runs its first arg, a script,
 * on completion (successful or otherwise).  Returns list of pids.
 * NB the stdout from the subprocess should be redirected, as it is used
 * to spot its termination and should not have anything sent to it.
 * The return code from the subprocess is not available.
 */

int MarkedExecCmd(ClientData clientData, Tcl_Interp *interp,
                  int argc, char **argv) {
    int outputId;			/* File id for output pipe.  -1
					 * means command overrode. */
    int *pids;
    int npids, result, keepNewline;
    int firstWord;
	int i;
	char id[50];


    if (argc < 3) { strcpy(interp->result, "wrong # args"); return TCL_ERROR; }

    

    npids = Tcl_CreatePipeline(interp, argc-2, argv+2,
                               &pids, (int*)0, &subout, (int*)0);
    if (npids < 0) return TCL_ERROR;
    Tcl_DetachPids(npids, pids);
    for (i=0; i<npids; i++) {
      sprintf(buf, "%d",pids[i]);
      Tcl_AppendElement(interp,id);
    }
    ckfree(pids);
    return TCL_OK;


    /*
     * Create the command's pipeline.
     */

    numPids = Tcl_CreatePipeline(interp, argc-firstWord, argv+firstWord,
	    &pidPtr, (int *) NULL, &outputId, &errorId);
    if (numPids < 0) {
	return TCL_ERROR;
    }

    /*
     * Read the child's output (if any) and put it into the result.
     */

    result = TCL_OK;
    if (outputId != -1) {
	while (1) {
#	    define BUFFER_SIZE 1000
	    char buffer[BUFFER_SIZE+1];
	    int count;
    
	    count = read(outputId, buffer, (size_t) BUFFER_SIZE);
    
	    if (count == 0) {
		break;
	    }
	    if (count < 0) {
		Tcl_ResetResult(interp);
		Tcl_AppendResult(interp,
			"error reading from output pipe: ",
			Tcl_PosixError(interp), (char *) NULL);
		result = TCL_ERROR;
		break;
	    }
	    buffer[count] = 0;
	    Tcl_AppendResult(interp, buffer, (char *) NULL);
	}
	close(outputId);
    }

    if (CleanupChildren(interp, numPids, pidPtr, errorId, keepNewline)
	    != TCL_OK) {
	result = TCL_ERROR;
    }
    return result;
}
